bundle

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 9, 2026 License: MIT Imports: 9 Imported by: 0

Documentation

Overview

Package bundle handles packing and unpacking of manifest archives.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DefaultConfigPaths

func DefaultConfigPaths(home string) []string

DefaultConfigPaths returns common dotfiles to include in a bundle.

func Pack

func Pack(manifestPath, outputPath string, opts PackOptions) error

Pack creates a tar.gz bundle from a manifest file.

func Unpack

func Unpack(bundlePath, destDir string) (string, error)

Unpack extracts a bundle to a directory and returns the manifest path.

Types

type Metadata

type Metadata struct {
	CliMigVersion   string    `json:"cli_mig_version"`
	CreatedAt       time.Time `json:"created_at"`
	ManifestPath    string    `json:"manifest_path"`
	IncludedConfigs []string  `json:"included_configs"`
	SourceOS        string    `json:"source_os"`
	SourceArch      string    `json:"source_arch"`
}

Metadata describes a bundle archive.

type PackOptions

type PackOptions struct {
	IncludeConfigs bool
	ConfigPaths    []string
}

PackOptions controls which extra files are included in a bundle.

Jump to