Documentation
¶
Overview ¶
Package bundle handles packing and unpacking of manifest archives.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DefaultConfigPaths ¶
DefaultConfigPaths returns common dotfiles to include in a bundle.
func Pack ¶
func Pack(manifestPath, outputPath string, opts PackOptions) error
Pack creates a tar.gz bundle from a manifest file.
Types ¶
type Metadata ¶
type Metadata struct {
CliMigVersion string `json:"cli_mig_version"`
CreatedAt time.Time `json:"created_at"`
ManifestPath string `json:"manifest_path"`
IncludedConfigs []string `json:"included_configs"`
SourceOS string `json:"source_os"`
SourceArch string `json:"source_arch"`
}
Metadata describes a bundle archive.
type PackOptions ¶
PackOptions controls which extra files are included in a bundle.
Click to show internal directories.
Click to hide internal directories.